==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/da.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Dine indstillinger er blevet opdateret.",
"Activity" => "Begivenhed",
"A file or folder has been <strong>shared</strong>" => "En fil eller mappe er blevet <strong>delt</strong>",
"A new file or folder has been <strong>created</strong> in a shared folder" => "En ny fil eller mappe er blevet <strong>oprettet</strong> i en delt mappe.",
"A file or folder has been <strong>changed</strong> in a shared folder" => "En ny fil eller mappe er blevet <strong>ændret</strong> i en delt mappe.",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "En ny fil eller mappe er blevet <strong>slettet</strong> i en delt mappe.",
"You created %1\$s" => "Du oprettede %1\$s ",
"%2\$s created %1\$s" => "%2\$s oprettede %1\$s",
"You changed %1\$s" => "Du ændrede %1\$s",
"%2\$s changed %1\$s" => "%2\$s ændrede %1\$s",
"You deleted %1\$s" => "Du slettede %1\$s",
"%2\$s deleted %1\$s" => "%2\$s slettede %1\$s",
"You shared %1\$s with %2\$s" => "Du delte %1\$s med %2\$s",
"You shared %1\$s with group %2\$s" => "Du delte %1\$s med gruppen %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s delt %1\$s med dig",
"Activity notification" => "Aktivitets notifikation",
"All Activities" => "Alle begivenheder",
"Activities by you" => "Begivenheder af dig",
"Activities by others" => "Begivenheder af andre",
"Shares" => "Delt",
"Files" => "Filer",
"%s and %s" => "%s og %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("",""),
"_%s and %n more_::_%s and %n more_" => array("",""),
"Hello %s," => "Hej %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Du modtager denne e-mail, fordi at der i løbet af den seneste time er sket følgende på %s",
"You are receiving this email because in the last day the following things happened at %s" => "Du modtager denne e-mail, fordi at der i løbet af den seneste dag er sket følgende på %s",
"You are receiving this email because in the last week the following things happened at %s" => "Du modtager denne e-mail, fordi at der i løbet af den seneste uge er sket følgende på %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Du vil se en liste over hendelser her, når du begynder at bruge din %s.",
"No more events to load" => "Ikke flere begivenheder at indlæse",
"Enable RSS feed" => "Aktiverer RSS feed",
"Notifications" => "Beskeder",
"Mail" => "Mail",
"Stream" => "Stream",
"You need to set up your email address before you can receive notification emails." => "Du skal indstille din e-mail adresse før du kan modtage notifikationer via e-mail.",
"Send emails:" => "Send e-mails:",
"Daily" => "Dagligt",
"Weekly" => "Ugentligt",
"Activity feed" => "Begivenheder",
"Personal activity feed for %s" => "Personlige begivenheder for %s "
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.1~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/da.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Dine indstillinger er blevet opdateret.",
"Activity" => "Begivenhed",
"A file or folder has been <strong>shared</strong>" => "En fil eller mappe er blevet <strong>delt</strong>",
"A new file or folder has been <strong>created</strong>" => "En ny fil eller mapper er blevet <strong>oprettet</strong>",
"A file or folder has been <strong>changed</strong>" => "En fil eller mappe er blevet <strong>ændret</strong>",
"A file or folder has been <strong>deleted</strong>" => "En fil eller mappe er blevet <strong>slettet</strong>",
"You created %1\$s" => "Du oprettede %1\$s ",
"%2\$s created %1\$s" => "%2\$s oprettede %1\$s",
"You changed %1\$s" => "Du ændrede %1\$s",
"%2\$s changed %1\$s" => "%2\$s ændrede %1\$s",
"You deleted %1\$s" => "Du slettede %1\$s",
"%2\$s deleted %1\$s" => "%2\$s slettede %1\$s",
"You shared %1\$s with %2\$s" => "Du delte %1\$s med %2\$s",
"You shared %1\$s with group %2\$s" => "Du delte %1\$s med gruppen %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s delt %1\$s med dig",
"You shared %1\$s via link" => "Du delte %1\$s via link",
"Activity notification" => "Aktivitets notifikation",
"All Activities" => "Alle begivenheder",
"Activities by you" => "Begivenheder af dig",
"Activities by others" => "Begivenheder af andre",
"Shares" => "Delt",
"Files" => "Filer",
"%s and %s" => "%s og %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s og <strong class=\"tooltip\" title=\"%s\">%n mere</strong>","%s og <strong class=\"tooltip\" title=\"%s\">%n andre</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s og %n mere","%s og %n flere"),
"Hello %s," => "Hej %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Du modtager denne e-mail, fordi at der i løbet af den seneste time er sket følgende på %s",
"You are receiving this email because in the last day the following things happened at %s" => "Du modtager denne e-mail, fordi at der i løbet af den seneste dag er sket følgende på %s",
"You are receiving this email because in the last week the following things happened at %s" => "Du modtager denne e-mail, fordi at der i løbet af den seneste uge er sket følgende på %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Du vil se en liste over hendelser her, når du begynder at bruge din %s.",
"No more events to load" => "Ikke flere begivenheder at indlæse",
"Enable RSS feed" => "Aktiverer RSS feed",
"Notifications" => "Beskeder",
"Mail" => "Mail",
"Stream" => "Stream",
"Notify about my own actions" => "Underet mig om mine egne handlinger",
"You need to set up your email address before you can receive notification emails." => "Du skal indstille din e-mail adresse før du kan modtage notifikationer via e-mail.",
"Send emails:" => "Send e-mails:",
"Hourly" => "I timen",
"Daily" => "Dagligt",
"Weekly" => "Ugentligt",
"Activity feed" => "Begivenheder",
"Personal activity feed for %s" => "Personlige begivenheder for %s "
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
